@@ -27,7 +27,7 @@ class FutureObject(object):
         Blocks until data is available.
         """
         self.__cond.acquire()
-        while not self.__available:
+        if not self.__available:
             self.__cond.wait(TIMEOUT)
         self.__cond.release()
 
